pygeodesy.ellipsoids.Ellipsoid2

Package pygeodesy :: Module ellipsoids :: Class Ellipsoid2 |
[frames] | no frames]

# Class Ellipsoid2

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
    named._NamedEnumItem --+
                           |
                   Ellipsoid --+
                               |
                              Ellipsoid2

An Ellipsoid specified by equatorial radius and flattening.

Instance Methods
__init__(self, a, f=None, **name) New Ellipsoid2. |
Inherited from `Ellipsoid`: `Llat`, `Lmeridian`, `Rgeocentric`, `Rlat`, `__eq__`, `__hash__`, `auxAuthalic`, `auxConformal`, `auxGeocentric`, `auxIsometric`, `auxParametric`, `auxRectifying`, `auxReduced`, `circle4`, `degrees2m`, `distance2`, `e2s`, `e2s2`, `ecef`, `es_atanh`, `es_tauf`, `es_taupf`, `geodesic_`, `hartzell4`, `height4`, `m2degrees`, `m2radians`, `radians2m`, `rhumb_`, `roc1_`, `roc2`, `roc2_`, `rocAzimuth`, `rocBearing`, `rocGauss`, `rocMean`, `rocMeridional`, `rocPrimeVertical`, `rocTransverse`, `toEllipse`, `toEllipsoid2`, `toStr`, `toTriaxial` Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Ellipsoid`: `A`, `AlphaKs`, `BetaKs`, `KsOrder`, `L`, `R1`, `R2`, `R2x`, `R3`, `Rauthalic`, `Rauthalicx`, `Rbiaxial`, `Requatorial`, `Rgeometric`, `Rmean`, `Rpolar`, `Rquadratic`, `Rr`, `Rrectifying`, `Rs`, `Rtriaxial`, `Rvolumetric`, `a`, `a2`, `a2_`, `a2_b`, `a2_b2`, `a_b`, `a_f`, `a_f2`, `area`, `areax`, `b`, `b2`, `b2_a`, `b2_a2`, `b_a`, `c`, `c2`, `c2x`, `e`, `e12`, `e2`, `e21`, `e22`, `e22abs`, `e2abs`, `e32`, `e32abs`, `e4`, `eccentricity`, `eccentricity1st2`, `eccentricity2nd2`, `eccentricity3rd2`, `equatoradius`, `equatorimeter`, `es`, `es_c`, `f`, `f1`, `f2`, `f_`, `flattening`, `flattening1st`, `flattening2nd`, `flattening3rd`, `geodesic`, `geodesicw`, `geodesicx`, `geodsolve`, `isEllipsoidal`, `isOblate`, `isProlate`, `isSpherical`, `majoradius`, `minoradius`, `n`, `polaradius`, `polarimeter`, `quarteradius`, `rhumbaux`, `rhumbekx`, `rhumbsolve`, `rhumbx`, `rocEquatorial2`, `rocPolar`, `volume` Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, a, f=None, **name) (Constructor) |
New Ellipsoid2. Arguments: `a` - Equatorial radius, semi-axis (`meter`) or a previous Ellipsoid instance. `f` - Flattening: (`float` < 1.0, negative for prolate), if `a` is in `meter`. `name` - Optional, unique `name=NN` (`str`). Raises: `NameError` - Ellipsoid with that `name` already exists. `ValueError` - Invalid `a` or `f`. Overrides: object.__init__ Note: `abs(f) < EPS` is forced to `f=0`, spherical. Negative `f` produces a prolate ellipsoid.